===========
policy.json
===========

The ``policy.json`` file defines additional access controls that apply
to the Shared File Systems service.

.. literalinclude:: ../../../../../etc/manila/policy.json
   :language: json
